/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.examples;

import java.awt.Color;
import java.awt.Container;
import java.awt.Graphics;
import java.awt.GridBagLayout;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.xml.xpath.XPath;
import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpression;
import javax.xml.xpath.XPathFactory;

import org.w3c.dom.NameList;
import org.w3c.dom.NodeList;

import net.sf.xcf.event.PublishEvent;
import net.sf.xcf.transport.Attachment;
import net.sf.xcf.util.SynchronizedQueue;
import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.Nodes;

public class FusedMapWindow extends JPanel {

    private PublishEvent result;
    private SynchronizedQueue<PublishEvent> queue;
    private float[] data;
    private int width;
    private int height;

    public FusedMapWindow(SynchronizedQueue<PublishEvent> queue) {
        this.queue = queue;
    }

    @Override
    public void paintComponent(Graphics g) {
        super.paintComponent(g);
        g.setColor(Color.BLACK);
        try {
            this.repaint();
            result = queue.next(1000);
            if (result != null) {
                Attachment a = result.getData().getAttachment("slammap");
                String s = result.getData().getDocumentAsText();
                Builder parser = new Builder();
                Document doc = parser.build(result.getData().getDocumentAsText(), "SLAMMAP");
                this.width = Integer.parseInt(doc.getRootElement().getChildElements("SLAMMAP").get(0).getChildElements("PROPERTIES").get(0).getAttributeValue("mapwidth"));
                this.height = Integer.parseInt(doc.getRootElement().getChildElements("SLAMMAP").get(0).getChildElements("PROPERTIES").get(0).getAttributeValue("mapheight"));
                /*
                this.height =
                        Integer.parseInt(s.substring(
                                s.indexOf("mapheight=\"") + 11, s.indexOf("\"",
                                        s.indexOf("mapheight=\"") + 11)));
                this.width =
                        Integer.parseInt(s.substring(
                                s.indexOf("mapwidth=\"") + 10, s.indexOf("\"",
                                        s.indexOf("mapwidth=\"") + 10)));
                 */
                float[] b = a.getAsFloatArray();
                this.data = b;
            }
            if (this.data != null) {
                for (int i = 0; i < this.data.length; i++) {
                    int x = i / this.height * g.getClipBounds().width / this.width;
                    int y = (g.getClipBounds().height-1)-(i % this.height * g.getClipBounds().height / this.height);
                    g.setColor(new Color(this.data[i], this.data[i],
                            this.data[i]));
                    
                    g.fillRect(x, y, g.getClipBounds().width / this.width, g.getClipBounds().height / this.height);
                }
            }
        } catch (Exception e) {
            System.err.println("Error");
            e.printStackTrace();
        }
    }
}
